import "./styles.sass";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faDroplet, faGear, faMessage, faPalette} from "@fortawesome/free-solid-svg-icons";
import DesignItem from "@/states/Manage/pages/ManageChannel/components/DesignItem";
import SettingsItem from "@/states/Manage/pages/ManageChannel/components/SettingsItem";
import {useContext, useEffect, useState} from "react";
import DesignImage from "@/common/images/design.png";
import {useParams} from "react-router-dom";
import {ChannelContext} from "@/states/Manage/pages/Channels/contexts/ChannelContext";

export const ManageChannel = () => {

    const params = useParams();
        const {channels, getChannelById} = useContext(ChannelContext);
        const [currentChannel, setCurrentChannel] = useState();

        useEffect(() => {
            if (channels) setCurrentChannel(getChannelById(params.channel));
        }, [channels]);

        if (!currentChannel) return;

    return (
        <div className="manage-channel">
            <div className="manage-section">
                <FontAwesomeIcon icon={faGear} />
                <h1>Settings</h1>
            </div>

            <SettingsItem name="Language" description="Which language should be chosen for this channel?" type="langCode"
                          options={[{id: "en", value: "English"}, {id: "de", value: "Deutsch"}]} current={currentChannel.langCode} />

            <SettingsItem name="Topic" description="What is this channel about?" type="topic"
                            options={[{id: "1", value: "General"}, {id: "2", value: "Gaming"},
                                {id: "3", value: "Coding"}, {id: "4", value: "Anime"}]} current={currentChannel.topic} />

            <div className="manage-section">
                <FontAwesomeIcon icon={faPalette} />
                <h1>Design</h1>
            </div>

            <div className="design-container">

                <DesignItem name="Default" coins="500" perks={[
                    {icon: faMessage, name: "Embed-Message"},
                    {icon: faDroplet, name: "Colorful design"}
                ]} id={1} image={DesignImage} />

                <DesignItem name="Better" coins="500" perks={[
                    {icon: faMessage, name: "Embed-Message"},
                    {icon: faDroplet, name: "Colorful design"}
                ]} id={2} image={DesignImage} />

                <DesignItem name="Default" coins="500" perks={[
                    {icon: faMessage, name: "Embed-Message"},
                    {icon: faDroplet, name: "Colorful design"}
                ]} id={3} image={DesignImage} />

                <DesignItem name="Better" coins="500" perks={[
                    {icon: faMessage, name: "Embed-Message"},
                    {icon: faDroplet, name: "Colorful design"}
                ]} id={4} image={DesignImage}/>
            </div>
        </div>
    );
}